import React, { useState, useEffect, useRef } from 'react';
import { StyleSheet } from 'react-native';
import { View as MotiView, useDynamicAnimation } from 'moti';
const styles = StyleSheet.create({
    autoBottom: {
        bottom: 'auto'
    },
    hidden: {
        overflow: 'hidden'
    }
});
export function AnimateHeight({ children, hide = false, style, delay = 0, transition = {
    type: 'spring',
    delay
}, initialHeight = 0 }) {
    const animation = useDynamicAnimation(() => ({
        height: hide ? 0 : initialHeight
    }));
    const [measuredHeight, setHeight] = useState(initialHeight);
    let height = measuredHeight;
    if (hide) {
        height = 0;
    }
    const mounted = useRef(false);
    useEffect(function mount() {
        mounted.current = true;
        return () => {
            mounted.current = false;
        };
    }, []);
    useEffect(function updateHeight() {
        var _a;
        if (hide) {
            animation.animateTo({
                height: 0
            });
        }
        else if (((_a = animation.current) === null || _a === void 0 ? void 0 : _a.height) !== height) {
            animation.animateTo({
                height
            });
        }
    }, [animation, height, hide]);
    const notVisible = !height || hide;
    return (React.createElement(MotiView, { state: animation, transition: transition, style: [style, height || hide ? styles.hidden : {}] },
        React.createElement(MotiView, { style: [StyleSheet.absoluteFillObject, styles.autoBottom], animate: { opacity: notVisible ? 0 : 1 }, transition: transition, onLayout: (next) => {
                if (mounted.current) {
                    setHeight(next.nativeEvent.layout.height);
                }
            } }, children)));
}
//# sourceMappingURL=index.native.js.map