import React, { useCallback, useRef } from 'react';
import { useVirtualizer, defaultRangeExtractor } from '@tanstack/react-virtual';
export function VirtualizerWrapper({ data, estimatedItemSize, horizontal, keyExtractor, rangeExtractor, children, customWebContainerStyle }) {
    const parentRef = useRef(null);
    const virtualizer = useVirtualizer({
        count: data.length,
        getScrollElement: () => parentRef.current,
        estimateSize: () => estimatedItemSize,
        horizontal,
        getItemKey: keyExtractor
            ? (index) => {
                return keyExtractor(data[index], index);
            }
            : undefined,
        rangeExtractor: useCallback((range) => {
            rangeExtractor === null || rangeExtractor === void 0 ? void 0 : rangeExtractor(range);
            return defaultRangeExtractor(range);
        }, [rangeExtractor])
    });
    return (React.createElement("div", { ref: parentRef, style: customWebContainerStyle
            ? Object.assign({ overflow: 'auto' }, customWebContainerStyle) : {
            top: 0,
            left: 0,
            right: 0,
            bottom: 0,
            display: 'flex',
            flex: '1 1 0%',
            overflow: 'auto',
            position: 'absolute'
        } }, children(virtualizer)));
}
//# sourceMappingURL=VirtualizerWrapper.js.map