import React, { PureComponent } from 'react';
import { VirtualizerWrapper } from './VirtualizerWrapper';
export class VirtualList extends PureComponent {
    constructor() {
        super(...arguments);
        this.virtualizer = null;
        this.rangeRef = null;
        this.scrollToIndex = (index) => {
            var _a;
            (_a = this.virtualizer) === null || _a === void 0 ? void 0 : _a.scrollToIndex(index, { align: 'end' });
            const timeout = setTimeout(() => {
                if (this.rangeRef !== null) {
                    const { startIndex, endIndex } = this.rangeRef;
                    const isVisible = index >= startIndex && index <= endIndex;
                    if (!isVisible) {
                        this.scrollToIndex(index);
                    }
                    else {
                        clearTimeout(timeout);
                    }
                }
            }, 300);
        };
    }
    componentDidMount() {
        if (this.props.initialScrollIndex != null) {
            this.scrollToIndex(this.props.initialScrollIndex);
        }
    }
    scrollToEnd() {
        const lastIndex = this.props.data.length - 1;
        this.scrollToIndex(lastIndex);
    }
    render() {
        const { data, renderItem, estimatedItemSize, horizontal, keyExtractor, customWebContainerStyle } = this.props;
        return (React.createElement(VirtualizerWrapper, { data: data, estimatedItemSize: estimatedItemSize, horizontal: horizontal, keyExtractor: keyExtractor, rangeExtractor: (range) => {
                this.rangeRef = range;
            }, customWebContainerStyle: customWebContainerStyle }, (virtualizer) => {
            this.virtualizer = virtualizer;
            return (React.createElement("div", { style: {
                    height: horizontal ? '100%' : virtualizer.getTotalSize(),
                    width: horizontal ? virtualizer.getTotalSize() : '100%',
                    position: 'relative'
                } }, virtualizer.getVirtualItems().map((virtualRow) => {
                return (React.createElement("div", { key: virtualRow.key, "data-index": virtualRow.index, ref: virtualizer.measureElement, style: Object.assign({ position: 'absolute', top: 0, left: 0, transform: horizontal
                            ? `translateX(${virtualRow.start}px)`
                            : `translateY(${virtualRow.start}px)` }, (horizontal ? { height: '100%' } : { width: '100%' })) }, renderItem({ item: data[virtualRow.index], index: virtualRow.index })));
            })));
        }));
    }
}
//# sourceMappingURL=index.js.map