var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React, { useCallback, useEffect, useMemo, useState, forwardRef, useRef } from 'react';
import { View } from 'react-native';
import { Pressable } from '../../interactive/buttons/Pressable';
import { Layer } from '../../layout';
import { Modal } from '../modals';
import { getNativePlacementOffsetStyle } from './utils/getNativePlacementOffsetStyle';
import { styleVariants } from './utils/styleVariants';
const Popover = forwardRef((_a, ref) => {
    var { active, placement = 'bottom', popoverChildren, popoverContainerProps, onRequestClose, children, modalBackgroundColor } = _a, others = __rest(_a, ["active", "placement", "popoverChildren", "popoverContainerProps", "onRequestClose", "children", "modalBackgroundColor"]);
    const [anchorViewLayout, setAnchorViewLayout] = useState();
    const [popoverViewLayout, setPopoverViewLayout] = useState({ x: 0, y: 0, height: 0, width: 0 });
    const anchorRef = useRef();
    const styles = useMemo(() => {
        if (active && anchorViewLayout != null && popoverViewLayout.height !== 0 && popoverViewLayout.width !== 0) {
            return getNativePlacementOffsetStyle(anchorViewLayout, popoverViewLayout, placement);
        }
        else {
            return {
                opacity: 0
            };
        }
    }, [active, anchorViewLayout, placement, popoverViewLayout]);
    const onPopoverLayout = useCallback(({ nativeEvent: { layout } }) => {
        setPopoverViewLayout(layout);
    }, []);
    const measureInWindow = useCallback(() => {
        var _a;
        (_a = anchorRef.current) === null || _a === void 0 ? void 0 : _a.measureInWindow((x, y, width, height) => {
            setAnchorViewLayout({ x, y, width: Math.ceil(width), height: Math.ceil(height) });
        });
    }, []);
    useEffect(() => {
        if (active) {
            measureInWindow();
        }
    }, [active, measureInWindow]);
    return (React.createElement(Layer, Object.assign({ ref: ref }, others),
        children(anchorRef),
        React.createElement(Modal, { visible: active },
            React.createElement(Pressable, { zIndex: 0, onPress: onRequestClose, position: 'absolute', width: '100%', height: '100%', from: styleVariants.initial, animate: styleVariants.visible, exit: styleVariants.initial, backgroundColor: modalBackgroundColor }),
            React.createElement(View, { style: [{ position: 'absolute', zIndex: 2 }, styles] },
                React.createElement(Layer, Object.assign({ onLayout: onPopoverLayout, from: styleVariants.initial, animate: styleVariants.visible, exit: styleVariants.initial }, popoverContainerProps), popoverChildren(anchorViewLayout === null || anchorViewLayout === void 0 ? void 0 : anchorViewLayout.width))))));
});
Popover.displayName = 'Popover';
export { Popover };
//# sourceMappingURL=index.native.js.map