import React from 'react';
import { Button } from '../../interactive/buttons/Button';
import { Box } from '../../layout/Box';
import { DimmedModal } from '../modals/DimmedModal';
import { Text } from '../../text/Text';
import { PaddingLayer } from '../../layout/PaddingLayer';
import { HorizontalLayer } from '../../layout/HorizontalLayer';
import { useTheme } from '../../../context/hooks/useTheme';
export function AlertModal({ visible, onDismiss, title, message, buttons = [{ text: 'Ok', style: 'default', onPress: () => { } }] }) {
    const { spacings } = useTheme();
    const validButtons = [...buttons].splice(0, 3).reverse();
    const [firstButton, secondButton, thirdButton] = validButtons;
    const getButtonVariantForAlertButtonStyle = (style) => {
        switch (style) {
            case 'cancel':
                return 'content';
            case 'destructive':
                return 'danger';
            default:
                return 'main';
        }
    };
    const handleButtonPress = (button) => {
        return () => {
            var _a;
            onDismiss();
            (_a = button.onPress) === null || _a === void 0 ? void 0 : _a.call(button);
        };
    };
    return (React.createElement(DimmedModal, { visible: visible, onDismiss: onDismiss },
        React.createElement(PaddingLayer, { marginTop: 48, alignItems: 'center' },
            React.createElement(Box, { maxWidth: 448, style: { width: '100%' } },
                React.createElement(Text, { fontWeight: 'bold', marginBottom: spacings.s }, title),
                React.createElement(Text, { marginBottom: spacings.m }, message),
                React.createElement(HorizontalLayer, { justifyContent: thirdButton != null ? 'space-between' : 'flex-end' },
                    thirdButton != null ? (React.createElement(Button, { text: thirdButton.text, onPress: handleButtonPress(thirdButton), variant: getButtonVariantForAlertButtonStyle(thirdButton.style) })) : null,
                    React.createElement(HorizontalLayer, { alignItems: 'center' },
                        secondButton != null ? (React.createElement(Button, { text: secondButton.text, onPress: handleButtonPress(secondButton), variant: getButtonVariantForAlertButtonStyle(secondButton.style), marginRight: spacings.s })) : null,
                        React.createElement(Button, { text: firstButton === null || firstButton === void 0 ? void 0 : firstButton.text, onPress: handleButtonPress(firstButton), variant: getButtonVariantForAlertButtonStyle(firstButton === null || firstButton === void 0 ? void 0 : firstButton.style) })))))));
}
//# sourceMappingURL=AlertModal.js.map