import React, { useCallback, useState } from 'react';
import { createPortal } from 'react-dom';
import { Toast } from '../Toast';
import { TOAST_DURATIONS } from '../toastDurations';
import { ToastContext } from '../../../../context/ToastContext';
import { Layer } from '../../../layout/Layer';
import { AnimatePresence } from '../../../animation/AnimatePresence';
import { useTheme } from '../../../../context/hooks/useTheme';
function generateUEID() {
    let first = (Math.random() * 46656) | 0;
    let second = (Math.random() * 46656) | 0;
    first = `000${first.toString(36)}`.slice(-3);
    second = `000${second.toString(36)}`.slice(-3);
    return `${first}${second}`;
}
export function ToastProvider({ children }) {
    const { spacings } = useTheme();
    const [toasts, setToasts] = useState([]);
    const open = useCallback((message, options = {
        duration: TOAST_DURATIONS.SHORT
    }) => {
        setToasts((currentToasts) => {
            return [...currentToasts, { id: generateUEID(), message, duration: options.duration }];
        });
    }, []);
    const close = useCallback((id) => setToasts((currentToasts) => currentToasts.filter((toast) => toast.id !== id)), []);
    return (React.createElement(ToastContext.Provider, { value: open },
        children,
        toasts.length > 0
            ? createPortal(React.createElement(Layer, { layout: true, overflow: 'hidden', position: 'absolute', bottom: 12, right: 20, minWidth: 300, maxWidth: 560 },
                React.createElement(AnimatePresence, null, toasts.map((toast) => {
                    return (React.createElement(Toast, { key: toast.id, message: toast.message, close: () => close(toast.id), duration: toast.duration, margin: spacings.s }));
                }))), document.body)
            : null));
}
//# sourceMappingURL=index.js.map